What is Pyskool? — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# What is Pyskool?

In 1984, Microsphere published Skool Daze, a game for the Sinclair ZX Spectrum. In 1985, the sequel Back to Skool was published.

Each game was based in a boys’ school (though Back to Skool added a playground and a girls’ school) and revolved around the antics of Eric, the hero. In Skool Daze, Eric must steal his report card from the school safe - the combination of which must be extracted from the teachers’ brains using flashing shields or, in the case of the history teacher, post-hypnotic suggestion. In Back to Skool, Eric must get his report card back into the school safe, this time with the extra help provided by a water pistol, stinkbombs, a bike, mice, a frog and a girlfriend.

Pyskool is a re-implementation of these classic games in Python and Pygame, with the aim of making them easy to customise by editing a configuration file or - for more advanced customisation - writing some Python code.

The latest version of Pyskool can always be obtained from pyskool.ca.

## Licence and copyrights

Pyskool is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. See the file ‘COPYING’ (distributed with Pyskool) for the full text of the licence.

The copyright in the original ZX Spectrum game code and graphics for both Skool Daze and Back to Skool is held by Microsphere Computer Services Ltd.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »